Stan Math Library: stan/math/rev/mat/fun/LDLT_factor.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
LDLT_factor.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/LDLT_alloc.hpp>`
`#include <stan/math/prim/mat/fun/LDLT_factor.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`

Go to the source code of this file.

## Classes
class | stan::math::LDLT_factor< stan::math::var, R, C >
| A template specialization of src/stan/math/matrix/LDLT_factor.hpp for stan::math::var which can be used with all the *_ldlt functions. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.